import json
from django.urls import reverse
from rest_framework import status
from rest_framework.test import APITestCase
from ..models import Sale, Product, Customer


class TestAPI(APITestCase):
    def setUp(self):
        self.product = Product.objects.create(
            name='Panela',
            price=5000,
            measuring_unit='UNIT'
        )
        self.customer = Customer.objects.create(
            name='Camilo'
        )

    def test_create_sale(self):
        response = self._create_sale()
        content = json.loads(response.content.decode('utf-8'))
        self.assertEqual(response.status_code, status.HTTP_201_CREATED)
        self.assertEqual(Sale.objects.count(), 1)
        sale = Sale.objects.all()[0]
        self.assertEqual(
            sale.customer.name,
            self.customer.name
        )
        self.assertEqual(
            sale.id,
            content['id']
        )

    def test_get_products(self):
        url = '/don_confiao/api/products/'
        response = self.client.get(url)
        json_response = json.loads(response.content.decode('utf-8'))
        self.assertEqual(response.status_code, 200)
        self.assertEqual(self.product.name, json_response[0]['name'])

    def test_get_customers(self):
        url = '/don_confiao/api/customers/'
        response = self.client.get(url)
        json_response = json.loads(response.content.decode('utf-8'))
        self.assertEqual(response.status_code, 200)
        self.assertEqual(self.customer.name, json_response[0]['name'])

    def _create_sale(self):
        url = '/don_confiao/api/sales/'
        data = {
            'customer': self.customer.id,
            'date': '2024-09-02',
            'payment_method': 'CASH',
            'saleline_set': [
                {'product': self.product.id, 'quantity': 2, 'unit_price': 3000},
                {'product': self.product.id, 'quantity': 3, 'unit_price': 5000}
            ],
        }
        return self.client.post(url, data, format='json')
