#!/usr/bin/env python3
from django.test import Client, TestCase
from io import StringIO
import csv


class TestExportSales(TestCase):
    fixtures = ['sales_fixture']

    def setUp(self):
        self.client = Client()

    def test_export_sales(self):
        sales_response = self._export_sales_csv()
        filename = sales_response.headers[
            'Content-Disposition'].split('; ')[1].strip('filename=').strip("'")
        content = sales_response.content
        content_str = content.decode('utf-8')
        csv_file = StringIO(content_str)
        header = next(csv.reader(csv_file))

        self.assertGreater(len(content), 0)
        self.assertEqual(filename, 'sales.csv')
        self.assertEqual(sales_response.headers['Content-Type'], 'text/csv')
        self.assertEqual(header, self._tryton_sale_header())

    def _export_sales_csv(self):
        return self.client.get("/don_confiao/exportar_ventas_para_tryton")

    def _tryton_sale_header(self):
        return [
            "Tercero",
            "Dirección de facturación",
            "Dirección de envío",
            "Descripción",
            "Referencia",
            "Fecha venta",
            "Plazo de pago",
            "Almacén",
            "Moneda",
            "Líneas/Producto",
            "Líneas/Cantidad",
            "Líneas/Precio unitario",
            "Líneas/Unidad",
            "Empresa",
            "Tienda",
            "Terminal de venta",
            "Autorecogida",
            "Comentario"
                ]
