from django.test import TestCase, Client
from ..models import Sale, Product, SaleLine, Customer


class TestSummaryViewPurchase(TestCase):
    def setUp(self):
        customer = Customer()
        customer.name = 'Alejo Mono'
        customer.save()

        self.client = Client()
        purchase = Sale()
        purchase.customer = customer
        purchase.date = "2024-07-30"
        purchase.clean()
        purchase.save()

        product = Product()
        product.name = "cafe"
        product.price = "72500"
        product.save()

        line = SaleLine()
        line.sale = purchase
        line.product = product
        line.quantity = "11"
        line.unit_price = "72500"
        line.save()
        self.purchase = purchase

    def test_summary_has_customer(self):
        url = "/don_confiao/resumen_compra/" + str(self.purchase.id)
        response = self.client.get(url)
        self.assertEqual(response.status_code, 200)
        self.assertEqual(
            response.context["purchase"].customer,
            self.purchase.customer
        )
        self.assertIn('Alejo Mono', response.content.decode('utf-8'))

    def test_json_summary(self):
        url = f"/don_confiao/resumen_compra_json/{self.purchase.id}"
        response = self.client.get(url)
        content = response.content.decode('utf-8')
        self.assertEqual(response.status_code, 200)
        self.assertIn('Alejo Mono', content)
        self.assertIn('cafe', content)
        self.assertIn('72500', content)
        self.assertIn('quantity', content)
        self.assertIn('11', content)
        self.assertIn('date', content)
        self.assertIn(self.purchase.date, content)
        self.assertIn('lines', content)
